@@ -2,9 +2,9 @@
 
 # Build zipfiles for Pango on Win32: separate runtime and developer packages
 
-ZIP=/tmp/pango-1.10.1-`date +%Y%m%d`.zip
-DEVZIP=/tmp/pango-dev-1.10.1-`date +%Y%m%d`.zip
-cd /opt/rendering
+ZIP=/tmp/pango-1.10.2-`date +%Y%m%d`.zip
+DEVZIP=/tmp/pango-dev-1.10.2-`date +%Y%m%d`.zip
+cd /home/behdad/.local
 
 rm $ZIP
 zip $ZIP -@ <<EOF
