@@ -783,7 +783,10 @@ itemize_state_fill_shaper (ItemizeState     *state,
       PangoItem *item = l->data;
       if (item->analysis.shape_engine)
 	break;
-      item->analysis.font = g_object_ref (font);
+      if (font)
+	item->analysis.font = g_object_ref (font);
+      else
+	item->analysis.font = NULL;
       item->analysis.shape_engine = shape_engine;
     }
 }
@@ -1140,6 +1143,8 @@ itemize_state_finish (ItemizeState *state)
   itemize_state_reset_shape_engines (state);
   if (state->current_fonts)
     g_object_unref (state->current_fonts);
+  if (state->base_font)
+    g_object_unref (state->base_font);
 }
 
 /**
@@ -1153,13 +1158,15 @@ itemize_state_finish (ItemizeState *state)
  *             This must be >= 0.
  * @base_dir:  base direction to use for bidirectional processing
  * @attrs:     the set of attributes that apply to @text.
- * @cached_iter:      Cached attribute iterator, or NULL
+ * @cached_iter:      Cached attribute iterator, or %NULL
  *
  * Like pango_itemize(), but the base direction to use when
  * computing bidirectional levels (see pango_context_set_base_dir ()),
  * is specified explicitely rather than gotten from the #PangoContext.
  *
  * Return value: a GList of PangoItem structures.
+ *
+ * Since: 1.4
  */
 GList *
 pango_itemize_with_base_dir (PangoContext      *context, 
@@ -1226,7 +1233,7 @@ itemize_with_font (PangoContext               *context,
  *             after @start_index.
  *             This must be >= 0.
  * @attrs:     the set of attributes that apply to @text.
- * @cached_iter:      Cached attribute iterator, or NULL
+ * @cached_iter:      Cached attribute iterator, or %NULL
  *
  * Breaks a piece of text into segments with consistent
  * directional level and shaping engine. Each byte of @text will
@@ -1333,8 +1340,11 @@ update_metrics_from_items (PangoFontMetrics *metrics,
   
   g_hash_table_destroy (fonts_seen);
   
-  metrics->approximate_char_width /= count;
-  metrics->approximate_digit_width /= count;
+  if (count)
+    {
+      metrics->approximate_char_width /= count;
+      metrics->approximate_digit_width /= count;
+    }
 }
 
 /**
@@ -1342,10 +1352,13 @@ update_metrics_from_items (PangoFontMetrics *metrics,
  * @context: a #PangoContext
  * @desc: a #PangoFontDescription structure
  * @language: language tag used to determine which script to get the metrics
- *            for, or %NULL to indicate to get the metrics for the entire
- *            font.
+ *            for. %NULL means that the language tag from the context will
+ *            be used. If no language tag is set on the ccontext, metrics
+ *            large enough to cover a range of languages will be returned.
+ *            The process of determining such metrics is slow, so it is best
+ *            to always make sure some real language tag will be used.
  * 
- * Get overall metric information for a font particular font
+ * Get overall metric information for a particular font
  * description.  Since the metrics may be substantially different for
  * different scripts, a language tag can be provided to indicate that
  * the metrics should be retrieved that correspond to the script(s)
@@ -1374,6 +1387,9 @@ pango_context_get_metrics (PangoContext                 *context,
   g_return_val_if_fail (PANGO_IS_CONTEXT (context), NULL);
   g_return_val_if_fail (desc != NULL, NULL);
 
+  if (!language)
+    language = context->language;
+
   current_fonts = pango_font_map_load_fontset (context->font_map, context, desc, language);
   metrics = get_base_metrics (current_fonts);
   
