@@ -58,7 +58,7 @@ struct PangoAlias
   gboolean visible; /* Do we want/need this? */
 };
 
-GHashTable *pango_aliases_ht = NULL;
+static GHashTable *pango_aliases_ht = NULL;
 
 /**
  * pango_trim_string:
@@ -1278,7 +1278,7 @@ pango_language_from_string (const char *language)
  *            %NULL is allowed and matches nothing but '*'
  * @range_list: a list of language ranges, separated by ';' characters.
  *   each element must either be '*', or a RFC 3066 language range
- *   canonicalized as by pango_language_from_string().
+ *   canonicalized as by pango_language_from_string()
  * 
  * Checks if a language tag matches one of the elements in a list of
  * language ranges. A language tag is considered to match a range
@@ -1427,10 +1427,10 @@ pango_log2vis_get_embedding_levels (gunichar       *str,
 
 /**
  * pango_get_mirror_char:
- * @ch: a unicode character
+ * @ch: a Unicode character
  * @mirrored_ch: location to store the mirrored character
  *
- * If @ch has the Unicode mirrored property and there is another unicode
+ * If @ch has the Unicode mirrored property and there is another Unicode
  * character that typically has a glyph that is the mirror image of @ch's
  * glyph, puts that character in the address pointed to by @mirrored_ch.
  *
@@ -1689,6 +1689,8 @@ pango_lookup_aliases (const char   *fontname,
  *
  * Return value: The direction corresponding to the first strong character.
  * If no such character is found, then %PANGO_DIRECTION_NEUTRAL is returned.
+ *
+ * Since: 1.4
  */
 PangoDirection
 pango_find_base_dir (const gchar *text,
@@ -1714,3 +1716,39 @@ pango_find_base_dir (const gchar *text,
 
   return dir;
 }
+
+/**
+ * pango_is_zero_width:
+ * @ch: a Unicode character
+ *
+ * Checks @ch to see if it is a zero-width character that should not be
+ * normally rendered on the screen.
+ *
+ * Return value: %TRUE if @ch is a zero-width character, %FALSE otherwise
+ *
+ * Since: 1.10
+ */
+gboolean
+pango_is_zero_width (gunichar ch)
+{
+/* Zero Width characters:
+ *
+ *  200B  ZERO WIDTH SPACE
+ *  200C  ZERO WIDTH NON-JOINER
+ *  200D  ZERO WIDTH JOINER
+ *  200E  LEFT-TO-RIGHT MARK
+ *  200F  RIGHT-TO-LEFT MARK
+ *  2028  LINE SEPARATOR
+ *  202A  LEFT-TO-RIGHT EMBEDDING
+ *  202B  RIGHT-TO-LEFT EMBEDDING
+ *  202C  POP DIRECTIONAL FORMATTING
+ *  202D  LEFT-TO-RIGHT OVERRIDE
+ *  202E  RIGHT-TO-LEFT OVERRIDE
+ *  FEFF  ZERO WIDTH NO-BREAK SPACE
+ */
+  return ((ch & ~(gunichar)0x003F) == 0x2000 && (
+		(ch >= 0x200B && ch <= 0x200F) ||
+		ch == 0x2028 ||
+		(ch >= 0x202A && ch <= 0x202E)
+	 )) || ch == 0xFEFF;
+}
