@@ -30,6 +30,7 @@
 #include "pangocairo-private.h"
 #include "pangocairo-fc.h"
 #include "pangofc-private.h"
+#include "pango-utils.h"
 
 #define PANGO_TYPE_CAIRO_FC_FONT           (pango_cairo_fc_font_get_type ())
 #define PANGO_CAIRO_FC_FONT(object)        (G_TYPE_CHECK_INSTANCE_CAST ((object), PANGO_TYPE_CAIRO_FC_FONT, PangoCairoFcFont))
@@ -226,20 +227,55 @@ pango_cairo_fc_font_get_glyph_info (PangoFont   *font,
   return info;
 }
      
-static void
-pango_cairo_fc_font_get_glyph_extents (PangoFont      *font,
-				       PangoGlyph      glyph,
-				       PangoRectangle *ink_rect,
-				       PangoRectangle *logical_rect)
+/* This function is cut-and-pasted from pangocairo-fcfont.c - it might be
+ * better to add a virtual fcfont->create_context (font).
+ */
+static PangoFontMetrics *
+pango_cairo_fc_font_get_metrics (PangoFont     *font,
+				 PangoLanguage *language)
 {
-  PangoCairoFcGlyphInfo *info;
+  PangoFcFont *fcfont = PANGO_FC_FONT (font);
+  PangoCairoFcFont *cffont = PANGO_CAIRO_FC_FONT (font);
+  PangoFcMetricsInfo *info = NULL; /* Quiet gcc */
+  GSList *tmp_list;      
 
-  info = pango_cairo_fc_font_get_glyph_info (font, glyph);
+  const char *sample_str = pango_language_get_sample_string (language);
   
-  if (ink_rect)
-    *ink_rect = info->ink_rect;
-  if (logical_rect)
-    *logical_rect = info->logical_rect;
+  tmp_list = fcfont->metrics_by_lang;
+  while (tmp_list)
+    {
+      info = tmp_list->data;
+      
+      if (info->sample_str == sample_str)    /* We _don't_ need strcmp */
+	break;
+
+      tmp_list = tmp_list->next;
+    }
+
+  if (!tmp_list)
+    {
+      PangoContext *context;
+
+      if (!fcfont->fontmap)
+	return pango_font_metrics_new ();
+
+      info = g_new0 (PangoFcMetricsInfo, 1);
+      
+      fcfont->metrics_by_lang = g_slist_prepend (fcfont->metrics_by_lang, 
+						 info);
+	
+      info->sample_str = sample_str;
+
+      context = pango_fc_font_map_create_context (PANGO_FC_FONT_MAP (fcfont->fontmap));
+      pango_context_set_language (context, language);
+      pango_cairo_context_set_font_options (context, cffont->options);
+
+      info->metrics = pango_fc_font_create_metrics_for_context (fcfont, context);
+
+      g_object_unref (context);
+    }
+
+  return pango_font_metrics_ref (info->metrics);
 }
 
 static FT_Face
@@ -267,6 +303,22 @@ pango_cairo_fc_font_real_get_unknown_glyph (PangoFcFont *font,
   return 0;
 }
 
+static void
+pango_cairo_fc_font_get_glyph_extents (PangoFont      *font,
+				       PangoGlyph      glyph,
+				       PangoRectangle *ink_rect,
+				       PangoRectangle *logical_rect)
+{
+  PangoCairoFcGlyphInfo *info;
+
+  info = pango_cairo_fc_font_get_glyph_info (font, glyph);
+  
+  if (ink_rect)
+    *ink_rect = info->ink_rect;
+  if (logical_rect)
+    *logical_rect = info->logical_rect;
+}
+
 static void
 pango_cairo_fc_font_shutdown (PangoFcFont *fcfont)
 {
@@ -293,6 +345,7 @@ pango_cairo_fc_font_class_init (PangoCairoFcFontClass *class)
   object_class->finalize = pango_cairo_fc_font_finalize;
   
   font_class->get_glyph_extents = pango_cairo_fc_font_get_glyph_extents;
+  font_class->get_metrics = pango_cairo_fc_font_get_metrics;
 
   fc_font_class->lock_face = pango_cairo_fc_font_lock_face;
   fc_font_class->unlock_face = pango_cairo_fc_font_unlock_face;
@@ -316,9 +369,30 @@ pango_cairo_fc_font_init (PangoCairoFcFont *cffont)
 static double
 get_font_size (PangoCairoFcFontMap        *cffontmap,
 	       PangoContext               *context,
-	       const PangoFontDescription *desc)
+	       const PangoFontDescription *desc,
+	       FcPattern                  *pattern)
 {
-      
+  double size;
+
+ /* The reason why we read FC_PIXEL_SIZE here rather than just
+  * using the specified size is to support operations like clamping 
+  * a font to a minimal readable size in fonts.conf. This is pretty weird, 
+  * since it could mean that changing the Cairo CTM doesn't change the 
+  * font size, but it's just a more radical version of the non-linear
+  * font scaling we already have due to hinting and due to bitmap
+  * fonts being only available at a few sizes.
+  * 
+  * If honoring FC_PIXEL_SIZE gets in the way of more useful features
+  * it should be removed since it only matters in the unusual case
+  * of people doing exotic stuff in fonts.conf.
+  */
+
+  if (FcPatternGetDouble (pattern, FC_PIXEL_SIZE, 0, &size) == FcResultMatch)
+    return size * PANGO_SCALE;
+
+  /* Just in case FC_PIXEL_SIZE got unset between pango_fc_make_pattern()
+   * and here.
+   */
   if (pango_font_description_get_size_is_absolute (desc))
     return pango_font_description_get_size (desc);
   else
@@ -363,7 +437,7 @@ _pango_cairo_fc_font_new (PangoCairoFcFontMap        *cffontmap,
   else
     cairo_matrix_init_identity (&cffont->font_matrix);
 
-  size = get_font_size (cffontmap, context, desc);
+  size = get_font_size (cffontmap, context, desc, pattern);
 
   cairo_matrix_scale (&cffont->font_matrix,
 		      size / PANGO_SCALE, size / PANGO_SCALE);
